function love.load()
	love.window.setMode(800, 400)
	love.graphics.setLineWidth(3)
	mousepressed = false --For touch conversion
	require "andralog"
	
	analog = newAnalog()
	--I called this function empty to have the default values
	--The arguments for non-default values are:
	--newAnalog(center's x, center's y, analog's radius, Button's radius, Deadzone's factor (from 0 to 1))
	
	player = {
		x = 350/2-50/2,
		y = 350/2-50/2,
		width = 50,
		height = 50,
		speedx = 0,
		speedy = 0,
		maxSpeed = 200,
		boundary = {0, 0, 350, 350}
	}
	
	local font = love.graphics.newFont(16)
	love.graphics.setFont(font)
	
	--[[
	self.spring = true
	self.reclick = true
	self.limitedRange = false
	self.rangeRelease = false
	]]
	checkboxes = {
		newCheckBox(50, 50, 16, 16, true, function(a) analog.spring = a end , "Spring"),
		newCheckBox(400-50-16-10-font:getWidth("Re-click"), 50, 16, 16, true, function(a) analog.reclick = a end, "Re-click"),
		newCheckBox(50, 400-50-8-font:getHeight()/2, 16, 16, false, function(a) analog.limitedRange = a end, "Limited range"),
		newCheckBox(400-50-16-10-font:getWidth("Range release"), 400-50-8-font:getHeight()/2, 16, 16, false, function(a) analog.rangeRelease = a end, "Range release")
	}
end

function love.draw()
	--analog screen
	analog.draw()
	
	--Player screen
	love.graphics.setColor(255, 255, 255, 155)
	love.graphics.line(400, 0, 400, 400)
	love.graphics.rectangle("line", 400+50/2, 50/2, 350, 350)
	
	love.graphics.setColor(0, 205, 255, 155)
	love.graphics.rectangle("fill", player.x+400+50/2, player.y+50/2, player.width, player.height)
	love.graphics.setColor(0, 205, 255, 255)
	love.graphics.rectangle("line", player.x+400+50/2, player.y+50/2, player.width, player.height)
	
	for i, v in ipairs(checkboxes) do
		v:draw()
	end
	
	--Mousey
	if mousepressed then
		love.graphics.setColor(255, 0, 0, 155)
		love.graphics.circle("fill", love.mouse.getX(), love.mouse.getY(), 8, 32)
	end
	love.graphics.setColor(255, 0, 0, 255)
	love.graphics.circle("line", love.mouse.getX(), love.mouse.getY(), 8, 32)
end

function love.update(dt)
	--Touch conversion
	if mousepressed then
		love.touchmoved(1, love.mouse.getX(), love.mouse.getY(), 0, 0, 1)
	end
	
	analog.update(dt)
	
	--Player positioning
	player.speedx = player.maxSpeed*analog.getX()
	player.speedy = player.maxSpeed*analog.getY()
	
	player.x = player.x + player.speedx*dt
	player.y = player.y + player.speedy*dt
	
	player.x = math.max(player.x, player.boundary[1])
	player.y = math.max(player.y, player.boundary[2])
	player.x = math.min(player.x, player.boundary[3]-player.width)
	player.y = math.min(player.y, player.boundary[4]-player.height)
	
	for i, v in ipairs(checkboxes) do
		v:update(dt)
	end
end

function love.touchpressed(id, x, y, dx, dy, pressure)
	analog.touchPressed(id, x, y, dx, dy, pressure)
	for i, v in ipairs(checkboxes) do
		v.touchPressed(id, x, y, dx, dy, pressure)
	end
end

function love.touchreleased(id, x, y, dx, dy, pressure)
	analog.touchReleased(id, x, y, dx, dy, pressure)
	for i, v in ipairs(checkboxes) do
		v.touchReleased(id, x, y, dx, dy, pressure)
	end
end

function love.touchmoved(id, x, y, dx, dy, pressure)
	analog.touchMoved(id, x, y, dx, dy, pressure)
	for i, v in ipairs(checkboxes) do
		v.touchMoved(id, x, y, dx, dy, pressure)
	end
end

function love.mousepressed(x, y, button)
	love.touchpressed(1, x, y, 0, 0, 1)
	mousepressed = true
end

function love.mousereleased(x, y, button)
	love.touchreleased(1, x, y, 0, 0, 1)
	mousepressed = false
end

function newCheckBox(x, y, width, height, state, func, text)
	local self = {}
	self.x = x
	self.y = y
	self.width = width or 16
	self.height = height or 16
	self.state = state
	if state == nil then
		self.state = false
	elseif state ~= false then
		self.state = true
	end
	
	self.text = text
	self.textOff = 10
	
	self.func = func or false
	self.font = love.graphics.getFont() or love.graphics.newFont(12)
	
	
	self.high = false
	self.down = false
	self.pressure = .5
	
	
	self.backOff =  {205, 205, 205, 255}
	self.backHigh = {235, 235, 235, 255}
	self.backDown = {205, 235, 255, 255}
	
	self.lineOff =  {105, 105, 105, 255}
	self.lineHigh = {135, 135, 135, 255}
	self.lineDown = { 95, 105, 135, 255}
	
	self.tickOff =  {  0, 105, 205, 255}
	self.tickHigh = { 35, 135, 235, 255}
	self.tickDown = {  0, 155, 255, 255}
	
	
	self.inside = function(x1, y1, w1, h1, x2, y2, w2, h2)
		if x1 >= x2 and x1+w1 <= x2+w2 and y1 >= y2 and y1+h1 <= y2+h2 then
			return true
		end
		return false
	end
	
	self.update = function(dt)
		local x, y = love.mouse.getPosition()
		self.high = false
		local add = 0
		if self.text then
			add = self.font:getWidth(tostring(self.text)) + self.textOff
		end
		if self.inside(x, y, 1, 1, self.x, self.y, self.width+add, self.height) then
			self.high = true
		end
	end
	
	self.draw = function()
		love.graphics.setFont(self.font)
		love.graphics.setColor(self.backOff)
		if self.high then
			love.graphics.setColor(self.backHigh)
			if self.down then
				love.graphics.setColor(self.backDown)
			end
		end
		
		love.graphics.rectangle("fill", self.x, self.y, self.width, self.height)
		
		
		love.graphics.setColor(self.lineOff)
		if self.high then
			love.graphics.setColor(self.lineHigh)
			if self.down then
				love.graphics.setColor(self.lineDown)
			end
		end
		
		love.graphics.rectangle("line", self.x, self.y, self.width, self.height)
		
		if self.text then
			local t = tostring(self.text)
			love.graphics.print(t, self.x+self.width+self.textOff, self.y+self.height/2-self.font:getHeight()/2)
		end
		
		
		if self.state == true then
			
			love.graphics.setColor(self.tickOff)
			if self.high then
				love.graphics.setColor(self.tickHigh)
				if self.down then
					love.graphics.setColor(self.tickDown)
				end
			end
			local xx, yy = self.x + self.width/8, self.y + self.height/8
			local ww, hh = self.width - self.width/4, self.height - self.height/4
			
			love.graphics.line(xx, yy+hh/2, xx+ww/2, yy+hh)
			love.graphics.line(xx+ww/2, yy+hh, xx+ww, yy)
			
		end
	end
	
	self.touchPressed = function(id, x, y, dx, dy, pressure)
		if not self.down then
			local add = 0
			if self.text then
				add = self.font:getWidth(tostring(self.text)) + self.textOff
			end
			if self.inside(x, y, 1, 1, self.x, self.y, self.width+add, self.height) then
				if pressure > self.pressure then
					self.down = id
				end
			end
		end
	end
	
	self.touchReleased = function(id, x, y, dx, dy, pressure)
		if self.down and id == self.down then
			self.release(x, y)
		end
	end
	
	self.touchMoved = function(id, x, y, dx, dy, pressure)
		if pressure < self.pressure and self.down and id == self.down then
			self.release(x, y)
		end
	end
	
	self.release = function(x, y)
		local add = 0
		if self.text then
			add = self.font:getWidth(tostring(self.text)) + self.textOff
		end
		if self.inside(x, y, 1, 1, self.x, self.y, self.width+add, self.height) and self.down then
			self.state = not self.state
			if self.func then
				self.func( self.state )
			end
		end
		self.down = false
	end
	
	return self
end